@@ -525,7 +525,7 @@ rc_service_exists(const char *service)
 }
 librc_hidden_def(rc_service_exists)
 
-#define OPTSTR ". '%s'; echo $opts"
+#define OPTSTR ". '%s'; echo $extra_commands $extra_started_commands"
 RC_STRINGLIST *
 rc_service_extra_commands(const char *service)
 {
@@ -550,14 +550,16 @@ rc_service_extra_commands(const char *service)
 	if ((fp = popen(cmd, "r"))) {
 		rc_getline(&buffer, &len, fp);
 		p = buffer;
-		while ((token = strsep(&p, " "))) {
-			if (!commands)
-				commands = rc_stringlist_new();
-			rc_stringlist_add(commands, token);
-		}
+		commands = rc_stringlist_new();
+
+		while ((token = strsep(&p, " ")))
+			if (token[0] != '\0')
+				rc_stringlist_add(commands, token);
+
 		pclose(fp);
 		free(buffer);
 	}
+
 	free(cmd);
 	return commands;
 }
@@ -747,7 +749,7 @@ rc_service_state(const char *service)
 
 	if (state & RC_SERVICE_STOPPED) {
 		dirs = ls_dir(RC_SVCDIR "/scheduled", 0);
-		TAILQ_FOREACH (dir, dirs, entries) {
+		TAILQ_FOREACH(dir, dirs, entries) {
 			snprintf(file, sizeof(file),
 			    RC_SVCDIR "/scheduled/%s/%s",
 			    dir->value, service);
@@ -890,7 +892,7 @@ rc_services_in_runlevel_stacked(const char *runlevel)
 
 	list = rc_services_in_runlevel(runlevel);
 	stacks = rc_runlevel_stacks(runlevel);
-	TAILQ_FOREACH (stack, stacks, entries) {
+	TAILQ_FOREACH(stack, stacks, entries) {
 		sl = rc_services_in_runlevel(stack->value);
 		if (list != NULL) {
 			TAILQ_CONCAT(list, sl, entries);
@@ -1006,7 +1008,7 @@ rc_services_scheduled_by(const char *service)
 	RC_STRING *dir;
 	char file[PATH_MAX];
 
-	TAILQ_FOREACH (dir, dirs, entries) {
+	TAILQ_FOREACH(dir, dirs, entries) {
 		snprintf(file, sizeof(file), RC_SVCDIR "/scheduled/%s/%s",
 		    dir->value, service);
 		if (exists(file))
